dmqclib.prepare.step3\_select\_profiles package
===============================================

.. automodule:: dmqclib.prepare.step3_select_profiles
   :members:
   :show-inheritance:
   :undoc-members:

Submodules
----------

dmqclib.prepare.step3\_select\_profiles.dataset\_a module
---------------------------------------------------------

.. automodule:: dmqclib.prepare.step3_select_profiles.dataset_a
   :members:
   :show-inheritance:
   :undoc-members:

dmqclib.prepare.step3\_select\_profiles.select\_base module
-----------------------------------------------------------

.. automodule:: dmqclib.prepare.step3_select_profiles.select_base
   :members:
   :show-inheritance:
   :undoc-members:
